@@ -29,6 +29,13 @@ static int frequencyList[] =
     0  // end
 };
 
+static int bufferSizeList[] = 
+{
+    // in Bytes
+    256, 512, 1024, 2048, 4096, 8192, 16384, 32768,
+    0  // end
+};
+
 AudioDialog::AudioDialog(QWidget* parent, const char* name) 
 : AudioDialogData(parent,name)
 {
@@ -48,6 +55,8 @@ void AudioDialog::setButtons()
     bit16Btn->setChecked(config.precision==AudioConfig::BITS_16);
     monoBtn->setChecked(config.channels==AudioConfig::MONO);
     stereoBtn->setChecked(config.channels==AudioConfig::STEREO);
+    unsignedBtn->setChecked(config.encoding==AudioConfig::UNSIGNED_PCM);
+    signedBtn->setChecked(config.encoding==AudioConfig::SIGNED_PCM);
     
     int i = 0, foundIndex = 0;
     // Activate startup value in frequency box.
@@ -61,6 +70,18 @@ void AudioDialog::setButtons()
     };
     frequencyBox->setCurrentItem(foundIndex);
 
+    i = 0, foundIndex = 0;
+    // Activate startup value in buffer size box.
+    while (bufferSizeList[i] != 0)
+    {
+        if (config.bufSize >= bufferSizeList[i])
+        {
+            foundIndex = i;
+        }
+        i++;
+    };
+    bufferSizeBox->setCurrentItem(foundIndex);
+
     i = 0;
     // Activate startup value in driver box.
     while ( i < driverBox->count() )
@@ -94,6 +115,14 @@ void AudioDialog::setPrecision(int)
         config.precision = AudioConfig::BITS_16;
 }
 
+void AudioDialog::setEncoding(int)
+{
+    if (unsignedBtn->isChecked())
+      config.encoding = AudioConfig::UNSIGNED_PCM;
+    else
+      config.encoding = AudioConfig::SIGNED_PCM;
+}
+
 void AudioDialog::setChannels(int)
 {
     if (monoBtn->isChecked())
@@ -107,6 +136,11 @@ void AudioDialog::setFrequency(int)
     config.frequency = frequencyList[frequencyBox->currentItem()];
 }
 
+void AudioDialog::setBufferSize(int)
+{
+    config.bufSize = bufferSizeList[bufferSizeBox->currentItem()];
+}
+
 void AudioDialog::setDriver( const QString& name )
 {
     AudioDrivers::setDriver( name.data() );
