@@ -39,8 +39,10 @@ class AudioDialog : public AudioDialogData
  protected slots:
     
     void setPrecision(int);
+    void setEncoding(int);
     void setChannels(int);
     void setFrequency(int);
+    void setBufferSize(int);
     void setBitsPerSample(int p)  { setPrecision(p); }  // old name
     void setDriver( const QString& );
 };
