@@ -21,7 +21,10 @@ const int ConfigC::version = 1;
 const char* const ConfigC::groups[] =
 { 
     "Audio", "Emulation", "Mixer", "Misc", "Main Window",
-    "Playlist", "Playlist Editor", "HVSC / STIL", "Selector"
+    "Playlist", "Playlist Editor", "HVSC / STIL", "Selector", "SidId"
+#ifdef XSID_HAVE_TSID2
+    , "TSID2"
+#endif
 };
 
 const char* const ConfigC::keys[] =
@@ -44,8 +47,14 @@ const char* const ConfigC::keys[] =
     "PlaytimeDefault", "FadeOutDefault",
     // Selector
     "Directory", "SaveDir", "NameFilter", "Open",
+    // SidId
+    "SidIdFile",
     // Misc
     "ConfigVersion", "Usage", "ExpertMode",
     "X", "Y", "W", "H"
+#ifdef XSID_HAVE_TSID2
+    //tsid2
+    ,"BasePath", "Custom", "Number_N", "Number_T", "Engine"
+#endif
 };
 
