@@ -28,7 +28,10 @@ class ConfigC
     enum groupID
     {
         Audio = 0, Emulation, Mixer, Misc, MainWindow,
-        Playlist, PlaylistEditor, HVSC_STIL, Selector
+        Playlist, PlaylistEditor, HVSC_STIL, Selector, SidId
+#ifdef XSID_HAVE_TSID2
+        , TSID2
+#endif
     };
 
     enum keyID
@@ -42,8 +45,11 @@ class ConfigC
         HVSC_Root, STIL_ShowGlobal, STIL_ShowEntries, HVSC_BugEntries,
         STIL_AllOrSong, STIL_AutoResize, STIL_MaxHeight, STIL_Viewer,
         SongLenDB, PlaytimeDefault, FadeOutDefault, 
-        Dir, SaveDir, NameFilter, Open,
+        Dir, SaveDir, NameFilter, Open, SidIdFile,
         ConfigVersion, Usage, ExpertMode, X, Y, W, H
+#ifdef XSID_HAVE_TSID2
+        , BasePath, Custom, Number_N, Number_T, Engine
+#endif
     };
 };
 
