@@ -17,7 +17,7 @@
 #ifndef EMUDIALOG_H
 #define EMUDIALOG_H
 
-#include <sidplay/emucfg.h>
+#include "wrapper/emucfg.h"
 
 #include "EmuDialogData.h"
 
@@ -45,6 +45,7 @@ public:
     void newCLKsetting(int);
     void newMPUsetting(int);
     void newEMUsetting(int);
+    void newSIDsetting(int);
 
  signals:
 
