@@ -35,7 +35,7 @@ class HVSC_Config
 
     HVSC_Config()
     {
-        hvscRootPath = "/usr/share/hvsc-3.8";
+        hvscRootPath = "/usr/share/hvsc";
         showGlobalComments = true;
         showStilEntries = true;
         showBugListEntries = true;
