@@ -57,7 +57,7 @@ public:
     QList<HistoryItem> list;
     unsigned int maxItems;
 
-    HistoryFile* file;
+    class HistoryFile* file;
 };
 
 #endif  /* HISTORYDIALOG_H */
