@@ -370,7 +370,7 @@ void MainDialog::setup(ConfigFile* cfg, const QString& path, Player* p)
     connect(myPlaylistEditDlg,SIGNAL( playlistEditUpdateRequest(uint) ),myPlaylistDlg,SLOT( updateListPos(uint) ));
 
     // Give player access to a few widgets.
-    player->link(this, timeLCD, songTimeLCD, myPlaylistDlg);
+    player->link(this, timeLCD, songTimeLCD, myPlaylistDlg, infoField);
     // Give playlist dialogs access to list in player.
     myPlaylistEditDlg->takeList( player->getPlaylist() );
     myPlaylistDlg->takeList( player->getPlaylist() );
@@ -478,7 +478,8 @@ bool MainDialog::writeConfig()
     AudioConfig thisAudioConfig = myAudioDlg->getConfig();
     // Always save user`s sane fragmentation settings.
     extern AudioConfig bakAudioConfig;
-    thisAudioConfig.bufSize = bakAudioConfig.bufSize;
+    /// disable this: now bufSize is into the audio dialog
+    /// thisAudioConfig.bufSize = bakAudioConfig.bufSize;
     thisAudioConfig.maxFrags = bakAudioConfig.maxFrags;
     thisAudioConfig.fragSize = bakAudioConfig.fragSize;
     
@@ -701,7 +702,7 @@ void MainDialog::resizeEvent(QResizeEvent*)
         infoField->hide();
     else if ( !infoField->isVisible() )
         infoField->show();
-    playlistCheckBox->move(16,h-22);  //  16,200
+    playlistCheckBox->move(8,h-22);   //  8,200
     loopCheckBox->move(142,h-22);     // 142,200
     randomCheckBox->move(245,h-22);   // 245,200
 }
@@ -763,6 +764,8 @@ void MainDialog::showSidTuneInfo()
              player->getSidTuneWrapper()->getStartSong() );
     tmp += tmp2;
 #ifdef SID_WITH_SIDPLAY2
+    tmp2.sprintf("\nClock Freq: %s",player->getEmuEngine()->getClockFreqString() );
+    tmp += tmp2;
     tmp2.sprintf("\nSong speed: %s",player->getEmuEngine()->getSpeedString() );
     tmp += tmp2;
     tmp2.sprintf("\nSID model : %s",player->getEmuEngine()->getSidModelString() );
@@ -783,9 +786,10 @@ void MainDialog::showSidTuneInfo()
       player->getSidTune()->getDataLength()
     ).c_str() );
     tmp += tmp2;
+    tmp += "\nMultiSpeed: "; 
 #endif
     infoField->setText(tmp);
-            
+    player->setDisplayString(tmp);
     songLCD->display(player->getSidTuneWrapper()->getCurrentSong() );
 }
 
@@ -1209,7 +1213,7 @@ void MainDialog::about()
 {
     QString verCat = "SIDPLAY/X11   Version ";
     verCat += VERSION;
-    verCat += "\nby Simon White & Stefano Tognon\n\n";
+    verCat += "\nby Fabrizio Gennari & Simon White & Stefano Tognon\n\n";
 
     verCat += "from SIDPLAY/X11   Version ";
     verCat += "1.6.5.2";
