@@ -55,7 +55,7 @@ class SidIdDialog;
 
 class ConfigFile;
 class AudioConfig;
-class emuConfig;
+struct emuConfig;
 class HVSC_Config;
 class MixerConfig;
 class Player;
