@@ -309,8 +309,8 @@ bool Playlist::load(const QString& newFileName)
                 // Convert separators.
                 for (uint i=0; i<item->fileNameString.length(); i++)
                 {
-                    if (item->fileNameString[i] == '\\')
-                        item->fileNameString[i] = QDir::separator();
+                    if (item->fileNameString[(int)i] == '\\')
+                        item->fileNameString[(int)i] = QDir::separator();
                 }
                 if ( loadFormat==1 )
                 {
