@@ -69,7 +69,7 @@ bool PlaylistCheck::checkBaseDir(QWidget* parent, Playlist* playlist,
             else
             {
                 // Strip trailing slash.
-                if (dirName.length() && dirName[dirName.length()-1]==QDir::separator() )
+                if (dirName.length() && dirName[(int)(dirName.length()-1)]==QDir::separator() )
                     dirName.remove(dirName.length()-1,1);
                 playlist->baseDir = dirName;
                 playlist->setModified();
