@@ -22,5 +22,9 @@ $UIC -o PlaylistOptDialog.h PlaylistOptDialog.ui
 $UIC -i PlaylistOptDialog.h -o PlaylistOptDialog.cpp PlaylistOptDialog.ui
 $UIC -o PlaylistUpdateDialog.h PlaylistUpdateDialog.ui
 $UIC -i PlaylistUpdateDialog.h -o PlaylistUpdateDialog.cpp PlaylistUpdateDialog.ui
+$UIC -o TSID2DialogData.h TSID2Dialog.ui
+$UIC -i TSID2DialogData.h -o TSID2DialogData.cpp TSID2Dialog.ui
+$UIC -o SidIdDialogData.h SidIdDialog.ui
+$UIC -i SidIdDialogData.h -o SidIdDialogData.cpp SidIdDialog.ui
 $MV -f *.h ..
 $MV -f *.cpp ..
