@@ -17,7 +17,7 @@
 #ifndef SONGLENGTHFILE_H
 #define SONGLENGTHFILE_H
 
-#include <vector.h>
+#include <vector>
 
 #include "Base.h"
 #include "Item.h"
@@ -29,6 +29,7 @@ class SongLengthFile : public SongLengthDB
     ~SongLengthFile();
     bool init(const char* fileName);
     bool getSongLength(const char* md5digest, int songNum, SongLengthDBitem& item);
+    bool getStatus()  { return status; }
     const char* getErrorStr()  { return errorString; }
     
  private:
@@ -38,7 +39,7 @@ class SongLengthFile : public SongLengthDB
     bool status;
     const char* errorString;
         
-    vector<const char*> vec;
+    std::vector<const char*> vec;
 
     char* dbFileNameAbs;
     char* hvscRoot;
