@@ -23,6 +23,14 @@ const float VERSION_NO = 2.17;
 
 #define CERR_STIL_DEBUG if (STIL_DEBUG) cerr << "Line #" << __LINE__ << " STIL::"
 
+#ifndef HAVE_SNPRINTF
+#ifdef HAVE__SNPRINTF
+#define snprintf _snprintf
+#else
+#error Neither snprintf nor _snprintf available.
+#endif
+#endif
+
 // CONSTRUCTOR
 STIL::STIL()
 {
