@@ -3,7 +3,7 @@
 //
 // AUTHOR: LaLa
 // Email : LaLa@C64.org
-// (C) 1998-2000 by LaLa
+// Copyright (C) 1998, 2002 by LaLa
 //
 
 //
@@ -16,7 +16,8 @@
 #ifndef _STIL_H
 #define _STIL_H
 
-#include <fstream.h>
+#include <fstream>
+#include <cstdlib>     // For atof() and size_t
 #include "stilcomm.h"
 
 class STIL {
@@ -27,6 +28,7 @@ class STIL {
         enum STILField {
             all,
             name,
+            author,
             title,
             artist,
             comment
@@ -133,16 +135,16 @@ class STIL {
         //      What the possible combinations of tuneNo and field represent:
         //
         //      - tuneNo = 0, field = all : all of the STIL entry is returned.
-        //      - tuneNo = 0, field = comment : the tune-global comment is returned.
+        //      - tuneNo = 0, field = comment : the file-global comment is returned.
         //        (For single-tune entries, this returns nothing!)
         //      - tuneNo = 0, field = <other> : INVALID! (NULL is returned)
         //      - tuneNo != 0, field = all : all fields of the STIL entry for the
         //        given tune number are returned. (For single-tune entries, this is
         //        equivalent to saying tuneNo = 0, field = all.)
-        //        However, the tune-global comment is *NOT* returned with it any
+        //        However, the file-global comment is *NOT* returned with it any
         //        more! (Unlike in versions before v2.00.) It led to confusions:
         //        eg. when a comment was asked for tune #3, it returned the
-        //        tune-global comment even if there was no specific entry for tune #3!
+        //        file-global comment even if there was no specific entry for tune #3!
         //      - tuneNo != 0, field = <other> : the specific field of the specific
         //        tune number is returned. If the tune number doesn't exist (eg. if
         //        tuneNo=2 for single-tune entries, or if tuneNo=2 when there's no
@@ -274,15 +276,15 @@ class STIL {
         size_t baseDirLength;
 
         // File handles
-        ifstream stilFile;
-        ifstream bugFile;
+        std::ifstream stilFile;
+        std::ifstream bugFile;
 
         // Linked list of sections (subdirs) for easier positioning.
         // NOTE: There's always at least one (empty) member on these
         //  lists! (The pointers will never be NULL.)
         struct dirList {
             char *dirName;
-            streampos position;
+            std::streampos position;
             struct dirList *next;
         } *stilDirs, *bugDirs;
 
@@ -343,7 +345,7 @@ class STIL {
         //              inFile
         //      true  - everything is okay
         //
-        bool getDirs(ifstream& inFile, dirList *dirs, bool isSTILFile);
+        bool getDirs(std::ifstream& inFile, dirList *dirs, bool isSTILFile);
 
         //
         // positionToEntry()
@@ -357,7 +359,7 @@ class STIL {
         // RETURNS:
         //      true - if successful
         //      false - otherwise
-        bool positionToEntry(const char *entryStr, ifstream& inFile, dirList *dirs);
+        bool positionToEntry(const char *entryStr, std::ifstream& inFile, dirList *dirs);
 
         //
         // readEntry()
@@ -370,7 +372,7 @@ class STIL {
         //      buffer   - where to put the result to
         // RETURNS:
         //      NONE
-        void readEntry(ifstream& inFile, char *buffer);
+        void readEntry(std::ifstream& inFile, char *buffer);
 
         //
         // getField()
@@ -378,7 +380,7 @@ class STIL {
         // FUNCTION: Given a STIL formatted entry in 'buffer', a tune number,
         //           and a field designation, it returns the requested
         //           STIL field into 'result'.
-        //           If field=all, it also puts the tune-global comment (if it exists)
+        //           If field=all, it also puts the file-global comment (if it exists)
         //           as the first field into 'result'.
         // ARGUMENTS:
         //      result - where to put the resulting string to (if any)
@@ -421,19 +423,7 @@ class STIL {
         //      line   - char array to put the line into
         // RETURNS:
         //      NONE
-        void getStilLine(ifstream& infile, char *line);
-
-        //
-        // addNewLine()
-        //
-        // FUNCTION: Adds a newline to 'str' and terminates it with NULL
-        //           (takes into account the UNIX/DOS difference).
-        // ARGUMENTS:
-        //      str - string to add newline to
-        // RETURNS:
-        //      NONE
-        //
-        inline void addNewline(char *str);
+        void getStilLine(std::ifstream& infile, char *line);
 
         //
         // deleteDirList()
