@@ -16,7 +16,6 @@
 
 #include "EmuWrapper.h"
 #include "SidTuneMod.h"
-
 #include "emucfg.h"
 
 QString EmuWrapper::versionString;
@@ -284,3 +283,44 @@ void EmuWrapper::setVoiceVolume(int voice, ubyte_emuwt left, ubyte_emuwt right,
 #endif
 }
 
+int EmuWrapper::getCia1TA()
+{
+#ifdef SID_WITH_SIDPLAY2
+    return pEmuEngine->cia1_last_ta();
+#else
+    return -1;  // no value gived back
+#endif
+}
+
+int EmuWrapper::getClockSpeed()
+{
+#ifdef SID_WITH_SIDPLAY2
+    emuMutex.lock();
+    sid2_info_t info = pEmuEngine->info();
+    emuMutex.unlock();
+    return info.tuneInfo->clockSpeed;
+#else
+    return -1;  /// not implemented 
+#endif
+}
+
+#ifdef SID_WITH_SIDPLAY2
+const char* EmuWrapper::getClockFreqString()
+{
+    emuMutex.lock();
+    sid2_info_t info = pEmuEngine->info();
+    emuMutex.unlock();
+
+    switch (info.tuneInfo->clockSpeed) {
+      case SIDTUNE_CLOCK_UNKNOWN:
+        return "Unknown";
+      case SIDTUNE_CLOCK_PAL:
+        return "PAL";
+      case SIDTUNE_CLOCK_NTSC:
+        return "NTSC";
+      case SIDTUNE_CLOCK_ANY:
+        return "ANY";
+    }
+    return "";
+}
+#endif
